# PnsPy

[![Supported Python Versions](https://img.shields.io/pypi/pyversions/pnspy.svg)](https://pypi.python.org/pypi/pnspy/)
[![PyPI Version](https://img.shields.io/pypi/v/pnspy.svg)](https://pypi.python.org/pypi/pnspy/)
[![License](https://img.shields.io/github/license/JSS95/pnspy)](https://github.com/JSS95/pnspy/blob/master/LICENSE)
[![CI](https://github.com/JSS95/pnspy/actions/workflows/ci.yml/badge.svg)](https://github.com/JSS95/pnspy/actions/workflows/ci.yml)
[![CD](https://github.com/JSS95/pnspy/actions/workflows/cd.yml/badge.svg)](https://github.com/JSS95/pnspy/actions/workflows/cd.yml)
[![Docs](https://readthedocs.org/projects/pnspy/badge/?version=latest)](https://pnspy.readthedocs.io/en/latest/?badge=latest)

PnsPy is a lightweight Python package for principal nested spheres (PNS) analysis.

## Installation

```
$ pip install pnspy
```

## Documentation

The manual can be found online:

> https://pnspy.readthedocs.io

If you want to build the documentation yourself, get the source code and install with `[doc]` dependency.
Then, go to the `doc` directory and build the documentation:

```
$ pip install .[doc]
$ cd doc
$ make html
```

The documentation will be generated in the `build/html` directory. Open `index.html` to see the main page.
